
var getSvgAttributeNamespace = require('./get-svg-attribute-namespace')
var isBooleanAttribute = require('./is-boolean-attribute')
var isSvgElement = require('./is-svg-element')
var document = require('global-undom')

var normalizeEvent = function (ev) { return 'on' + ev.slice(2, ev.length).toLowerCase(); }

var isEventHandler = function (key) { return key.slice(0, 2) === 'on'; }

var isString = function (val) { return typeof val === 'string'; }

var createElement = function (transformAttrs, ref) {
  var node = ref.node;
  var children = ref.children;
  var attrs = ref.attrs;

  var el = isSvgElement(node)
    ? document.createElementNS('http://www.w3.org/2000/svg', node)
    : document.createElement(node)

  for (var nkey in attrs) {
    var ref$1 = transformAttrs(nkey, attrs[nkey]);
    var key = ref$1[0];
    var val = ref$1[1];

    if (isEventHandler(key)) {
      // add event listeners to the node directly
      el[normalizeEvent(key)] = val
    } else if (isBooleanAttribute(key)) {
      // if it's a truthy boolean value, set the value to its own key.
      // If it's a falsy boolean value, ignore the attribute
      val !== false && el.setAttribute(key, key)
    } else {
      // otherwise just set the attribute on the element. Set the
      // namespace if it's an svg
      var ns = getSvgAttributeNamespace(key)
      ns
        ? el.setAttributeNS(ns, key, val)
        : el.setAttribute(key, val)
    }
  }

  if (children.length === 0) { return el }

  children.forEach(function (child) {
    if (!child) { return }
    if (isString(child)) { child = document.createTextNode(child) }
    el.appendChild(child)
  })

  return el
}

module.exports = createElement
